@@ -13,7 +13,7 @@ import numpy as np
 from docarray import Document
 from docarray.helper import typename
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from docarray.typing import (
         DocumentArrayIndexType,
         DocumentArraySingletonIndexType,
@@ -63,6 +63,10 @@ class SetItemMixin:
         index: 'DocumentArrayIndexType',
         value: Union['Document', Sequence['Document']],
     ):
+        from docarray.helper import check_root_id
+
+        if self._is_subindex:
+            check_root_id(self, value)
 
         self._update_subindices_set(index, value)
         # set by offset
